@@ -1,4 +1,6 @@
-#include <omp.h>
+#ifdef _OPENMP
+   #include <omp.h>
+#endif
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
